 /* +--------------------------------------------------------------------------+
// ? 2002-2013 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: dGrowl.css,v 1.3.2.2 2016-10-17 07:56:04 jpermanne Exp $ */

.dGrowl-main {
	position: fixed;
	max-height: 100%;
	overflow-y: auto;
	overflow-x: hidden;
	z-index: 999;
}

.dGrowl-notification {
	margin: 5px;
	padding: 5px;
	width: 190px;
	opacity: 0;
	-webkit-transition: margin-left 1.5s ease, opacity 1s linear;
	-moz-transition: margin-left 1.5s ease, opacity 1s linear;
	-o-transition: margin-left 1.5s ease, opacity 1s linear;
	transition: margin-left 1.5s ease, opacity 1s linear;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	-webkit-box-shadow: 5px 5px 12px -10px , 1);
	box-shadow: 5px 5px 12px -10px , 1);
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
	color: #222;
}
.dGrowl-topRight {
	top: 50px;
	right: 5px;
}
/* -- CHANNELS -- */
.dGrowl-channel {
	z-index: 999;
	position: relative;
	padding: 0 4px;
	overflow: hidden;
	width: 220px;
	display: block;
}
/* -- NOTIFICATIONS -- */
.dGrowl-title {
	font-weight: bold;
	font-size: 0.9em;
}
.dGrowl-topRight .dGrowl-notification {
	margin-left: 235px;
}
.dGrowl-notification.dGrowl-visible {
	opacity: 1;
	margin-left: 0;
	margin-right: 0;
}
a.dGrowl-close-btn {
	color: inherit;
	font-variant: normal;
	text-decoration: none;
	cursor: pointer;
	float: right;
	margin: 0 4px;
	opacity: 0.4;
	font-size: 18px;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	font-weight: bold;
	font-style: normal;
}
a.dGrowl-close-btn:hover {
	opacity: 0.85;
	color: inherit;
	font-variant: normal;
	text-decoration: none;
	cursor: pointer;
	font-size: 18px;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	font-weight: bold;
	font-style: normal;
}
/* default notification*/
.dGrowl-notification {
	background-color: #c6e966;
    border: 1px solid #7FA909;
}
/* Custom notification styles! */
.dGrowl-channel-error .dGrowl-notification {
	background-color: rgb(242, 222, 222);
    border: 1px solid #B94A48;
}

/* default notification*/
.dGrowl-channel-service .dGrowl-notification {
	background-color: #c6e966;
    -webkit-transition: none;
	-moz-transition: none;
	-o-transition: none;
	transition: none;
}